@@ -159,7 +159,7 @@ class PCA(sk_pca.PCA, DiffprivlibMixin):
         svd_solver == 'full') this number is estimated from input data.  Otherwise it equals the parameter
         n_components, or the lesser value of n_features and n_samples if n_components is None.
 
-    n_features_ : int
+    n_features_in_ : int
         Number of features in the training data.
 
     n_samples_ : int
@@ -184,6 +184,10 @@ class PCA(sk_pca.PCA, DiffprivlibMixin):
         component analysis." In 2016 IEEE International Conference on Acoustics, Speech and Signal Processing (ICASSP),
         pp. 2339-2343. IEEE, 2016.
     """
+
+    _parameter_constraints = DiffprivlibMixin._copy_parameter_constraints(
+        sk_pca.PCA, "n_components", "copy", "whiten", "random_state")
+
     def __init__(self, n_components=None, *, epsilon=1.0, data_norm=None, centered=False, bounds=None, copy=True,
                  whiten=False, random_state=None, accountant=None, **unused_args):
         super().__init__(n_components=n_components, copy=copy, whiten=whiten, svd_solver='full', tol=0.0,
@@ -196,6 +200,11 @@ class PCA(sk_pca.PCA, DiffprivlibMixin):
 
         self._warn_unused_args(unused_args)
 
+    # Todo: Remove when scikit-learn v1.2 is a min requirement
+    @property
+    def n_features_(self):
+        return self.n_features_in_
+
     def _fit_full(self, X, n_components):
         self.accountant.check(self.epsilon, 0)
 
@@ -259,7 +268,7 @@ class PCA(sk_pca.PCA, DiffprivlibMixin):
         else:
             self.noise_variance_ = 0.
 
-        self.n_samples_, self.n_features_ = n_samples, n_features
+        self.n_samples_ = n_samples
         self.components_ = components_[:n_components]
         self.n_components_ = n_components
         self.explained_variance_ = explained_variance_[:n_components]
