@@ -30,7 +30,7 @@ class TestBernoulliNegExp(TestCase):
             self.assertIn(bernoulli_neg_exp(1), [0, 1])
 
     def test_bad_rng(self):
-        self.assertRaises(AttributeError, bernoulli_neg_exp, 1, "rng")
+        self.assertRaises(ValueError, bernoulli_neg_exp, 1, "rng")
 
     def test_output_domain(self):
         for i in range(1000):
@@ -43,3 +43,14 @@ class TestBernoulliNegExp(TestCase):
                                0.5, delta=0.025)
         self.assertAlmostEqual(sum(bernoulli_neg_exp(-np.log(0.1), self.rng) for _ in range(runs)) / runs,
                                0.1, delta=0.025)
+
+    def test_random_state(self):
+        rng_42a, rng_42b = np.random.RandomState(42), np.random.RandomState(42)
+        self.assertEqual([bernoulli_neg_exp(1, rng_42a) for _ in range(100)],
+                         [bernoulli_neg_exp(1, rng_42b) for _ in range(100)])
+
+        rng_42a = np.random.RandomState(42)
+        self.assertEqual([bernoulli_neg_exp(1, rng_42a)] * 100, [bernoulli_neg_exp(1, 42) for _ in range(100)])
+
+        self.assertNotEqual([bernoulli_neg_exp(1, rng_42a) for _ in range(100)],
+                            [bernoulli_neg_exp(1, rng_42a) for _ in range(100)])
