@@ -2,14 +2,10 @@ from unittest import TestCase
 import numpy as np
 
 from diffprivlib.mechanisms import Laplace
-from diffprivlib.utils import global_seed
 
 
 class TestLaplace(TestCase):
     def setup_method(self, method):
-        if method.__name__ .endswith("prob"):
-            global_seed(314159)
-
         self.mech = Laplace
 
     def teardown_method(self, method):
@@ -73,7 +69,7 @@ class TestLaplace(TestCase):
             mech.randomise("Hello")
 
     def test_zero_median_prob(self):
-        mech = self.mech(epsilon=1, delta=0, sensitivity=1)
+        mech = self.mech(epsilon=1, delta=0, sensitivity=1, random_state=0)
         vals = []
 
         for i in range(10000):
@@ -85,7 +81,7 @@ class TestLaplace(TestCase):
     def test_neighbours_prob(self):
         epsilon = 1
         runs = 10000
-        mech = self.mech(epsilon=epsilon, delta=0, sensitivity=1)
+        mech = self.mech(epsilon=epsilon, delta=0, sensitivity=1, random_state=0)
         count = [0, 0]
 
         for i in range(runs):
@@ -100,6 +96,18 @@ class TestLaplace(TestCase):
         self.assertGreater(count[0], count[1])
         self.assertLessEqual(count[0] / runs, np.exp(epsilon) * count[1] / runs + 0.1)
 
+    def test_random_state(self):
+        mech1 = self.mech(epsilon=1, sensitivity=1, random_state=42)
+        mech2 = self.mech(epsilon=1, sensitivity=1, random_state=42)
+        self.assertEqual([mech1.randomise(0) for _ in range(100)], [mech2.randomise(0) for _ in range(100)])
+
+        self.assertNotEqual([mech1.randomise(0)] * 100, [mech1.randomise(0) for _ in range(100)])
+
+        rng = np.random.RandomState(0)
+        mech1 = self.mech(epsilon=1, sensitivity=1, random_state=rng)
+        mech2 = self.mech(epsilon=1, sensitivity=1, random_state=rng)
+        self.assertNotEqual([mech1.randomise(0) for _ in range(100)], [mech2.randomise(0) for _ in range(100)])
+
     def test_bias(self):
         self.assertEqual(0.0, self.mech(epsilon=1, delta=0, sensitivity=1).bias(0))
 
