@@ -1,17 +1,15 @@
+import warnings
+
 import numpy as np
 from unittest import TestCase
 
 import pytest
 
 from diffprivlib.mechanisms import LaplaceBoundedDomain
-from diffprivlib.utils import global_seed
 
 
 class TestLaplaceBoundedDomain(TestCase):
     def setup_method(self, method):
-        if method.__name__ .endswith("prob"):
-            global_seed(314159)
-
         self.mech = LaplaceBoundedDomain
 
     def teardown_method(self, method):
@@ -54,7 +52,7 @@ class TestLaplaceBoundedDomain(TestCase):
             mech.randomise("Hello")
 
     def test_zero_median_prob(self):
-        mech = self.mech(epsilon=1, delta=0, sensitivity=1, lower=0, upper=1)
+        mech = self.mech(epsilon=1, delta=0, sensitivity=1, lower=0, upper=1, random_state=0)
         vals = []
 
         for i in range(10000):
@@ -65,21 +63,14 @@ class TestLaplaceBoundedDomain(TestCase):
 
     def test_neighbors_prob(self):
         epsilon = 1
-        runs = 10000
-        mech = self.mech(epsilon=1, delta=0, sensitivity=1, lower=0, upper=1)
-        count = [0, 0]
+        runs = 1000
+        mech = self.mech(epsilon=1, delta=0, sensitivity=1, lower=0, upper=1, random_state=0)
 
-        for i in range(runs):
-            val0 = mech.randomise(0)
-            if val0 <= 0.5:
-                count[0] += 1
+        count0 = (np.array([mech.randomise(0) for _ in range(runs)]) <= 0.5).sum()
+        count1 = (np.array([mech.randomise(1) for _ in range(runs)]) <= 0.5).sum()
 
-            val1 = mech.randomise(1)
-            if val1 <= 0.5:
-                count[1] += 1
-
-        self.assertGreater(count[0], count[1])
-        self.assertLessEqual(count[0] / runs, np.exp(epsilon) * count[1] / runs + 0.1)
+        self.assertGreater(count0, count1)
+        self.assertLessEqual(count0 / runs, np.exp(epsilon) * count1 / runs + 0.1)
 
     def test_within_bounds(self):
         mech = self.mech(epsilon=1, delta=0, sensitivity=1, lower=0, upper=1)
@@ -96,11 +87,23 @@ class TestLaplaceBoundedDomain(TestCase):
     def test_semi_inf_domain_inf_epsilon(self):
         mech = self.mech(epsilon=float("inf"), delta=0, sensitivity=1, lower=0.0, upper=float("inf"))
 
-        with pytest.warns(None) as w:
+        with warnings.catch_warnings(record=True) as w:
             self.assertIsNotNone(mech.randomise(0))
 
         self.assertFalse(w, "Warning thrown for LaplaceBoundedDomain")
 
+    def test_random_state(self):
+        mech1 = self.mech(epsilon=1, sensitivity=1, lower=0, upper=4, random_state=42)
+        mech2 = self.mech(epsilon=1, sensitivity=1, lower=0, upper=4, random_state=42)
+        self.assertEqual([mech1.randomise(0) for _ in range(100)], [mech2.randomise(0) for _ in range(100)])
+
+        self.assertNotEqual([mech1.randomise(0)] * 100, [mech1.randomise(0) for _ in range(100)])
+
+        rng = np.random.RandomState(0)
+        mech1 = self.mech(epsilon=1, sensitivity=1, lower=0, upper=4, random_state=rng)
+        mech2 = self.mech(epsilon=1, sensitivity=1, lower=0, upper=4, random_state=rng)
+        self.assertNotEqual([mech1.randomise(0) for _ in range(100)], [mech2.randomise(0) for _ in range(100)])
+
     def test_repr(self):
         repr_ = repr(self.mech(epsilon=1, delta=0, sensitivity=1, lower=0, upper=1))
         self.assertIn(".LaplaceBoundedDomain(", repr_)
